<?php

namespace Drupal\synapse\Hook;

use Drupal\Core\Controller\ControllerBase;

/**
 * PreprocessHtml.
 */
class PageAttachments extends ControllerBase {

  /**
   * Hook.
   */
  public static function hook(array &$page) {
    $config = \Drupal::config('synapse.settings');
    self::yandexMap($page, $config);
    self::yandexWebmaster($page, $config);
    self::googleWebmaster($page, $config);
    self::googleTagManager($page, $config);
  }

  /**
   * Google Tag Manager.
   */
  public static function googleTagManager(&$page, $config) {
    $path = \Drupal::service('path.current')->getPath();
    if ($config->get('gtm-id') && substr($path, 0, 7) != '/admin/') {
      $script = "(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':
        new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],
        j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src=
        '//www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);
        })(window,document,'script','dataLayer','" . $config->get('gtm-id') . "');\n";
      $page['#attached']['html_head'][] = [
        [
          '#tag' => 'script',
          '#value' => $script,
        ],
        'gtm',
      ];
    }
  }

  /**
   * Google webmaster.
   */
  public static function googleWebmaster(&$page, $config) {
    if ($config->get('wm-google')) {
      $page['#attached']['html_head'][] = [
        [
          '#tag' => 'meta',
          '#attributes' => [
            'name'    => 'google-site-verification',
            'content' => $config->get('wm-google'),
          ],
        ],
        'google',
      ];
    }
  }

  /**
   * Yandex webmaster.
   */
  public static function yandexWebmaster(&$page, $config) {
    if ($config->get('wm-yandex')) {
      $page['#attached']['html_head'][] = [
        [
          '#tag' => 'meta',
          '#attributes' => [
            'name'    => 'yandex-verification',
            'content' => $config->get('wm-yandex'),
          ],
        ],
        'yandex',
      ];
    }
  }

  /**
   * Yandex map.
   */
  public static function yandexMap(&$page, $config) {
    $path = \Drupal::service('path.current')->getPath();
    $enable = $config->get('yamap-enable');
    $attach = $config->get('yamap-attach');
    $display = FALSE;
    if ($enable == 'enable_contact' && $path == $config->get('yamap-path')) {
      $display = TRUE;
    }
    if ($enable == 'enable' && substr($path, 0, 7) != '/admin/') {
      $display = TRUE;
    }

    if ($display) {
      $page['#attached']['library'][] = 'synapse/synapse.contact';
      $page['#attached']['drupalSettings']['synapse']['contact'] = [
        'latitude'  => $config->get('map-latitude')?:39.868851844220124,
        'longitude' => $config->get('map-longitude')?:59.193704678739856,
        'zoom'      => $config->get('map-zoom')?:16,
        'name'      => $config->get('yamap-name')?:'Синапс',
        'offset_x'  => $config->get('map-offset_x'),
        'offset_y'  => $config->get('map-offset_y'),
        'attach'    => $attach,
      ];
      // MapIcon.
      $module = \Drupal::service('module_handler')->getModule('synapse')->getPath();
      $mapicon = "/$module/assets/images/yamap-ico.png";
      $page['#attached']['drupalSettings']['synmap']['icon'] = $mapicon;
    }
  }

}
